<h1><img src="https://docs.basedpyright.com/latest/img/readme_logo.png"> basedpyright</h1>

Basedpyright is a fork of [pyright](https://github.com/microsoft/pyright) with various type checking improvements, pylance features and more.

**[full documentation](https://docs.basedpyright.com)**

## installation

it's recommended to install basedpyright [via pypi](https://docs.basedpyright.com/latest/installation/command-line-and-language-server/#pypi-package-recommended) rather than npm. [see here](https://docs.basedpyright.com/latest/benefits-over-pyright/pypi-package-vscode-pinning/#ability-to-pin-the-version-used-by-vscode) for more information.

the basedpyright npm package is intended for users who are unable to use the pypi package for some reason, for example if you're using an operating system not [supported by nodejs-wheel](https://github.com/njzjz/nodejs-wheel?tab=readme-ov-file#available-builds) or a version of python older than 3.8.
